( cd usr/lib ; rm -rf libradius.so )
( cd usr/lib ; ln -sf libradius-1.0.2.so libradius.so )
( cd usr/lib ; rm -rf rlm_chap.so )
( cd usr/lib ; ln -sf rlm_chap-1.0.2.so rlm_chap.so )
( cd usr/lib ; rm -rf libradius-1.0.2.la )
( cd usr/lib ; ln -sf libradius.la libradius-1.0.2.la )
( cd usr/lib ; rm -rf rlm_acct_unique.so )
( cd usr/lib ; ln -sf rlm_acct_unique-1.0.2.so rlm_acct_unique.so )
( cd usr/lib ; rm -rf rlm_acct_unique-1.0.2.la )
( cd usr/lib ; ln -sf rlm_acct_unique.la rlm_acct_unique-1.0.2.la )
( cd usr/lib ; rm -rf rlm_always.so )
( cd usr/lib ; ln -sf rlm_always-1.0.2.so rlm_always.so )
( cd usr/lib ; rm -rf rlm_always-1.0.2.la )
( cd usr/lib ; ln -sf rlm_always.la rlm_always-1.0.2.la )
( cd usr/lib ; rm -rf rlm_attr_filter.so )
( cd usr/lib ; ln -sf rlm_attr_filter-1.0.2.so rlm_attr_filter.so )
( cd usr/lib ; rm -rf rlm_attr_filter-1.0.2.la )
( cd usr/lib ; ln -sf rlm_attr_filter.la rlm_attr_filter-1.0.2.la )
( cd usr/lib ; rm -rf rlm_attr_rewrite.so )
( cd usr/lib ; ln -sf rlm_attr_rewrite-1.0.2.so rlm_attr_rewrite.so )
( cd usr/lib ; rm -rf rlm_attr_rewrite-1.0.2.la )
( cd usr/lib ; ln -sf rlm_attr_rewrite.la rlm_attr_rewrite-1.0.2.la )
( cd usr/lib ; rm -rf rlm_eap.so )
( cd usr/lib ; ln -sf rlm_eap-1.0.2.so rlm_eap.so )
( cd usr/lib ; rm -rf rlm_chap-1.0.2.la )
( cd usr/lib ; ln -sf rlm_chap.la rlm_chap-1.0.2.la )
( cd usr/lib ; rm -rf rlm_counter.so )
( cd usr/lib ; ln -sf rlm_counter-1.0.2.so rlm_counter.so )
( cd usr/lib ; rm -rf rlm_counter-1.0.2.la )
( cd usr/lib ; ln -sf rlm_counter.la rlm_counter-1.0.2.la )
( cd usr/lib ; rm -rf rlm_detail.so )
( cd usr/lib ; ln -sf rlm_detail-1.0.2.so rlm_detail.so )
( cd usr/lib ; rm -rf rlm_detail-1.0.2.la )
( cd usr/lib ; ln -sf rlm_detail.la rlm_detail-1.0.2.la )
( cd usr/lib ; rm -rf rlm_digest.so )
( cd usr/lib ; ln -sf rlm_digest-1.0.2.so rlm_digest.so )
( cd usr/lib ; rm -rf rlm_digest-1.0.2.la )
( cd usr/lib ; ln -sf rlm_digest.la rlm_digest-1.0.2.la )
( cd usr/lib ; rm -rf libeap.so )
( cd usr/lib ; ln -sf libeap-1.0.2.so libeap.so )
( cd usr/lib ; rm -rf rlm_eap-1.0.2.la )
( cd usr/lib ; ln -sf rlm_eap.la rlm_eap-1.0.2.la )
( cd usr/lib ; rm -rf rlm_exec.so )
( cd usr/lib ; ln -sf rlm_exec-1.0.2.so rlm_exec.so )
( cd usr/lib ; rm -rf libeap-1.0.2.la )
( cd usr/lib ; ln -sf libeap.la libeap-1.0.2.la )
( cd usr/lib ; rm -rf rlm_eap_gtc.so )
( cd usr/lib ; ln -sf rlm_eap_gtc-1.0.2.so rlm_eap_gtc.so )
( cd usr/lib ; rm -rf rlm_eap_gtc-1.0.2.la )
( cd usr/lib ; ln -sf rlm_eap_gtc.la rlm_eap_gtc-1.0.2.la )
( cd usr/lib ; rm -rf rlm_eap_leap.so )
( cd usr/lib ; ln -sf rlm_eap_leap-1.0.2.so rlm_eap_leap.so )
( cd usr/lib ; rm -rf rlm_eap_leap-1.0.2.la )
( cd usr/lib ; ln -sf rlm_eap_leap.la rlm_eap_leap-1.0.2.la )
( cd usr/lib ; rm -rf rlm_eap_md5.so )
( cd usr/lib ; ln -sf rlm_eap_md5-1.0.2.so rlm_eap_md5.so )
( cd usr/lib ; rm -rf rlm_eap_md5-1.0.2.la )
( cd usr/lib ; ln -sf rlm_eap_md5.la rlm_eap_md5-1.0.2.la )
( cd usr/lib ; rm -rf rlm_eap_mschapv2.so )
( cd usr/lib ; ln -sf rlm_eap_mschapv2-1.0.2.so rlm_eap_mschapv2.so )
( cd usr/lib ; rm -rf rlm_eap_mschapv2-1.0.2.la )
( cd usr/lib ; ln -sf rlm_eap_mschapv2.la rlm_eap_mschapv2-1.0.2.la )
( cd usr/lib ; rm -rf rlm_eap_peap.so )
( cd usr/lib ; ln -sf rlm_eap_peap-1.0.2.so rlm_eap_peap.so )
( cd usr/lib ; rm -rf rlm_eap_peap-1.0.2.la )
( cd usr/lib ; ln -sf rlm_eap_peap.la rlm_eap_peap-1.0.2.la )
( cd usr/lib ; rm -rf rlm_eap_sim.so )
( cd usr/lib ; ln -sf rlm_eap_sim-1.0.2.so rlm_eap_sim.so )
( cd usr/lib ; rm -rf rlm_eap_sim-1.0.2.la )
( cd usr/lib ; ln -sf rlm_eap_sim.la rlm_eap_sim-1.0.2.la )
( cd usr/lib ; rm -rf rlm_eap_tls.so )
( cd usr/lib ; ln -sf rlm_eap_tls-1.0.2.so rlm_eap_tls.so )
( cd usr/lib ; rm -rf rlm_eap_tls-1.0.2.la )
( cd usr/lib ; ln -sf rlm_eap_tls.la rlm_eap_tls-1.0.2.la )
( cd usr/lib ; rm -rf rlm_eap_ttls.so )
( cd usr/lib ; ln -sf rlm_eap_ttls-1.0.2.so rlm_eap_ttls.so )
( cd usr/lib ; rm -rf rlm_eap_ttls-1.0.2.la )
( cd usr/lib ; ln -sf rlm_eap_ttls.la rlm_eap_ttls-1.0.2.la )
( cd usr/lib ; rm -rf rlm_expr.so )
( cd usr/lib ; ln -sf rlm_expr-1.0.2.so rlm_expr.so )
( cd usr/lib ; rm -rf rlm_exec-1.0.2.la )
( cd usr/lib ; ln -sf rlm_exec.la rlm_exec-1.0.2.la )
( cd usr/lib ; rm -rf rlm_files.so )
( cd usr/lib ; ln -sf rlm_files-1.0.2.so rlm_files.so )
( cd usr/lib ; rm -rf rlm_expr-1.0.2.la )
( cd usr/lib ; ln -sf rlm_expr.la rlm_expr-1.0.2.la )
( cd usr/lib ; rm -rf rlm_fastusers.so )
( cd usr/lib ; ln -sf rlm_fastusers-1.0.2.so rlm_fastusers.so )
( cd usr/lib ; rm -rf rlm_fastusers-1.0.2.la )
( cd usr/lib ; ln -sf rlm_fastusers.la rlm_fastusers-1.0.2.la )
( cd usr/lib ; rm -rf rlm_ldap.so )
( cd usr/lib ; ln -sf rlm_ldap-1.0.2.so rlm_ldap.so )
( cd usr/lib ; rm -rf rlm_files-1.0.2.la )
( cd usr/lib ; ln -sf rlm_files.la rlm_files-1.0.2.la )
( cd usr/lib ; rm -rf rlm_ippool.so )
( cd usr/lib ; ln -sf rlm_ippool-1.0.2.so rlm_ippool.so )
( cd usr/lib ; rm -rf rlm_ippool-1.0.2.la )
( cd usr/lib ; ln -sf rlm_ippool.la rlm_ippool-1.0.2.la )
( cd usr/lib ; rm -rf rlm_pap.so )
( cd usr/lib ; ln -sf rlm_pap-1.0.2.so rlm_pap.so )
( cd usr/lib ; rm -rf rlm_ldap-1.0.2.la )
( cd usr/lib ; ln -sf rlm_ldap.la rlm_ldap-1.0.2.la )
( cd usr/lib ; rm -rf rlm_mschap.so )
( cd usr/lib ; ln -sf rlm_mschap-1.0.2.so rlm_mschap.so )
( cd usr/lib ; rm -rf rlm_mschap-1.0.2.la )
( cd usr/lib ; ln -sf rlm_mschap.la rlm_mschap-1.0.2.la )
( cd usr/lib ; rm -rf rlm_ns_mta_md5.so )
( cd usr/lib ; ln -sf rlm_ns_mta_md5-1.0.2.so rlm_ns_mta_md5.so )
( cd usr/lib ; rm -rf rlm_ns_mta_md5-1.0.2.la )
( cd usr/lib ; ln -sf rlm_ns_mta_md5.la rlm_ns_mta_md5-1.0.2.la )
( cd usr/lib ; rm -rf rlm_realm.so )
( cd usr/lib ; ln -sf rlm_realm-1.0.2.so rlm_realm.so )
( cd usr/lib ; rm -rf rlm_pap-1.0.2.la )
( cd usr/lib ; ln -sf rlm_pap.la rlm_pap-1.0.2.la )
( cd usr/lib ; rm -rf rlm_passwd.so )
( cd usr/lib ; ln -sf rlm_passwd-1.0.2.so rlm_passwd.so )
( cd usr/lib ; rm -rf rlm_passwd-1.0.2.la )
( cd usr/lib ; ln -sf rlm_passwd.la rlm_passwd-1.0.2.la )
( cd usr/lib ; rm -rf rlm_preprocess.so )
( cd usr/lib ; ln -sf rlm_preprocess-1.0.2.so rlm_preprocess.so )
( cd usr/lib ; rm -rf rlm_preprocess-1.0.2.la )
( cd usr/lib ; ln -sf rlm_preprocess.la rlm_preprocess-1.0.2.la )
( cd usr/lib ; rm -rf rlm_radutmp.so )
( cd usr/lib ; ln -sf rlm_radutmp-1.0.2.so rlm_radutmp.so )
( cd usr/lib ; rm -rf rlm_radutmp-1.0.2.la )
( cd usr/lib ; ln -sf rlm_radutmp.la rlm_radutmp-1.0.2.la )
( cd usr/lib ; rm -rf rlm_sql.so )
( cd usr/lib ; ln -sf rlm_sql-1.0.2.so rlm_sql.so )
( cd usr/lib ; rm -rf rlm_realm-1.0.2.la )
( cd usr/lib ; ln -sf rlm_realm.la rlm_realm-1.0.2.la )
( cd usr/lib ; rm -rf rlm_unix.so )
( cd usr/lib ; ln -sf rlm_unix-1.0.2.so rlm_unix.so )
( cd usr/lib ; rm -rf rlm_sql-1.0.2.la )
( cd usr/lib ; ln -sf rlm_sql.la rlm_sql-1.0.2.la )
( cd usr/lib ; rm -rf rlm_sql_mysql.so )
( cd usr/lib ; ln -sf rlm_sql_mysql-1.0.2.so rlm_sql_mysql.so )
( cd usr/lib ; rm -rf rlm_unix-1.0.2.la )
( cd usr/lib ; ln -sf rlm_unix.la rlm_unix-1.0.2.la )
( cd usr/lib ; rm -rf rlm_x99_token.so )
( cd usr/lib ; ln -sf rlm_x99_token-1.0.2.so rlm_x99_token.so )
( cd usr/lib ; rm -rf rlm_x99_token-1.0.2.la )
( cd usr/lib ; ln -sf rlm_x99_token.la rlm_x99_token-1.0.2.la )
( cd usr/lib ; rm -rf rlm_checkval.so )
( cd usr/lib ; ln -sf rlm_checkval-1.0.2.so rlm_checkval.so )
( cd usr/lib ; rm -rf rlm_checkval-1.0.2.la )
( cd usr/lib ; ln -sf rlm_checkval.la rlm_checkval-1.0.2.la )
